﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)

##############################################################################
    # Menu Buttons 

    ## Images: 
    # choice_bg_idle.jpg
    # choice_bg_hover.jpg

    style.menu_choice_button.background = Frame("ui/choice_bg_idle.png",28,9)
    style.menu_choice_button.hover_background = Frame("ui/choice_bg_hover.png",28,9)
    
    # style.name_button.selected_background = Frame("choice_bg_idle.jpg",28,9)
    # style.name_button.selected_hover_background = Frame("choice_bg_idle.jpg",28,9)
    # style.name_button.insensitive_background = Frame("choice_bg_idle.jpg",28,9)
    
    style.menu_choice_button.yminimum = 39 
    #Sets height -- recommend exact height of your image

    ## Button Text 
    style.menu_choice.color = "#ffcc66"
    style.menu_choice.size = 22
    style.menu_choice.outlines = [(1, "#666633", 0, 0)]
    style.menu_choice.hover_color = "#ffffff"
    style.menu_choice.hover_outlines = [(1, "#666633", 0, 0)]
    
    style.file_picker_button.color = "#ffcc66"

    
##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window:
        xalign 0.5
        yalign 0.5
        has vbox

        text prompt:
            yoffset 36
            style "say_dialogue"
            xoffset 82
        
        input:
            id "input"
            style "say_dialogue"
            color "#666633"
            yoffset 36
            xoffset 107

    use quick_menu
        
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"

    imagemap:
        ground "ui/mm_ground.png"
        idle "ui/mm_idle.png"
        hover "ui/mm_hover.png"
        
        alpha False
       
        hotspot (78, 244, 192, 47) action Start()
        hotspot (66, 303, 118, 48) action ShowMenu("load")
        hotspot (17, 355, 215, 58) action ShowMenu("preferences")
        hotspot (17, 418, 215, 57) action ShowMenu("about")
        hotspot (66, 468, 120, 61) action ShowMenu("bonusmenu")
        hotspot (78, 532, 92, 57) action Help()
        hotspot (78, 592, 88, 46) action Quit(confirm=False)
        
init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    ## The various buttons.
    imagemap:
        ground "ui/navigation_ground.png"
        idle "ui/navigation_idle.png"
        hover "ui/navigation_hover.png"
        selected_idle "ui/navigation_selected_idle.png"
        selected_hover "ui/navigation_selected_hover.png"
        
        alpha False
       
        hotspot (122, 681,107, 85) action Return()
        hotspot (243, 682, 94, 84) action ShowMenu("save")
        hotspot (351, 686, 80, 77) action ShowMenu("load")
        hotspot (458, 684, 162, 81) action ShowMenu("preferences")
        hotspot (636, 687, 168, 78) action MainMenu()
        hotspot (814, 684,71, 78) action Quit()
    
    
init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    # Format the description, and add it as text.
                    $ description = "% 2s. %s\n%s" % (
                        FileSlotName(i, columns * rows),
                        FileTime(i, empty=_("Empty Slot.")),
                        FileSaveName(i))

                    text description

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)

    

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces
    
screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            # frame:
                # style_group "pref"
                # has vbox
 
                # textbutton _("Joystick...") action Preference("joystick")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            # frame:
                # style_group "pref"
                # has vbox

                # label _("Voice Volume")
                # bar value Preference("voice volume")

                # if config.sample_voice:
                    # textbutton "Test":
                        # action Play("voice", config.sample_voice)
                        # style "soundtest_button"

init -2 python:
    ## frame
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    ## button
    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 0.5
    
    style.pref_button.background = Frame("ui/button_idle.png",10,10)
    style.pref_button.hover_background = Frame("ui/button_hover.png",10,10)
    style.pref_button.selected_background = Frame("ui/button_selected.png",10,10)
    style.pref_button.selected_hover_background = Frame("ui/button_hover.png",10,10)
    style.pref_button.yminimum = 40
    
    ## Button text
    style.pref_button_text.color = "#ffffcc"
    style.pref_button_text.size = 20
    # style.pref_button_text.font = "verdanab.ttf"
    style.pref_button_text.outlines = [(1, "#663300", 0, 0)]
    style.pref_button_text.hover_outlines = [(1, "#663366", 0, 0)]
    style.pref_button_text.selected_outlines = [(1, "#663300", 0, 0)]
    style.pref_button_text.selected_hover_outlines = [(1, "#663366", 0, 0)]
    
    # Label text 
    style.pref_label.xalign = 0.5
    style.pref_label_text.color = "#ffffff"
    style.pref_label_text.size = 34
    style.pref_label_text.font = "LHFmisterspookyREG_0.TTF"
    style.pref_label_text.outlines = [(1, "#666633", 0, 0)]
    style.pref_label_text.drop_shadow = [(2, 2)] 
    style.pref_label_text.drop_shadow_color = "#000000"
    
    ## frame box
    style.pref_frame.background = Frame("ui/frame.png",10,10)

    ## slider
    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 0.5
    
    style.pref_slider.left_bar = "ui/bar_full.png"
    style.pref_slider.right_bar = "ui/bar_empty.png"
    style.pref_slider.hover_left_bar = "ui/bar_hover.png"
    style.pref_slider.ymaximum = 29
    style.pref_slider.xmaximum = 197
    
    style.pref_slider.thumb = "ui/thumb.png"
    style.pref_slider.thumb_shadow = None
    style.pref_slider.thumb_offset = 6

    style.soundtest_button.xalign = 1.0
    
##############################################################################
# Bonus Menu
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation

screen bonusmenu:
     
    tag menu
    use navigation  
      
    # window:
        # style "gm_root"

    ## The various buttons.
     
    imagemap:
        ground "ui/bonus_ground.png"
        idle "ui/bonus_idle.png"
        hover "ui/bonus_hover.png"
       
        alpha False
        
        hotspot (69, 38, 272, 73) action ShowMenu("gallery")
        hotspot (89, 117, 198, 68) action ShowMenu("music_room")
        hotspot (129, 192, 150, 60) action ShowMenu("credits")
 
  
init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    
##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 1.0
        yalign 1.0

        # textbutton _("Q.Save") action QuickSave()
        #textbutton _("Q.Load") action QuickLoad()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Load") action ShowMenu('load')
        textbutton _("Skip") action Skip()
        # textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 0
    style.quick_button.ypadding = 10
    style.quick_button.right_padding = 25
    
    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 16
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    